#Clear the console of all previous objects. 
rm(list=ls(all=TRUE))

#Import data

raw<- read.csv("asbc.csv")


dry1<-data.frame(cbind(id=raw$fish.id, 
                       strm=raw$river, 
                       ls=raw$life.stage, 
                       fl=raw$fk.lgt, 
                       ww=raw$cut.wt.g,
                       dw.1=raw$dry.wt/100,#dry weight associated with macropanel analysis. Dry wt determined by freeze drying by UGuelph AFL 
                       dw.2=raw$dry.wt.sil, #dry weight associated with C/N analysis. Dry wt determined by oven drying in Leroux lab
                       P=((raw$P/1000000)/(raw$dry.wt/100))*100, 
                       N=raw$n.dry, 
                       C=raw$c.dry,
                       S=((raw$S/1000000)/(raw$dry.wt/100))*100,
                       Mg=((raw$Mg/1000000)/(raw$dry.wt/100))*100, 
                       K=((raw$K/1000000)/(raw$dry.wt/100))*100,
                       Na=((raw$Na/1000000)/(raw$dry.wt/100))*100,
                       Fe=((raw$Fe/1000000)/(raw$dry.wt/100))*100,
                       Ca=((raw$Ca/1000000)/(raw$dry.wt/100))*100)
)
dry1$ls<-as.factor(dry1$ls)
dry1$strm<-as.factor(dry1$strm)

#########################################
wet1<-data.frame(cbind
                 (id=raw$fish.id, 
                  strm=raw$river, 
                  ls=raw$life.stage, 
                  fl=raw$fk.lgt, 
                  wt=raw$cut.wt.g,
                  dw.1=raw$dry.wt/100, #dry weight associated with macropanel analysis. Dry wt determined by freeze drying by UGuelph AFL 
                  dw.2=raw$dry.wt.sil, #dry weight associated with C/N analysis. Dry wt determined by oven drying in Leroux lab
                  C=raw$C.wet*100, 
                  N=raw$N.wet*100, 
                  P=(raw$P/1000000)*100, #From macropanel analysis
                  Ca=(raw$Ca/1000000)*100,
                  S=(raw$S/1000000)*100,
                  Mg=(raw$Mg/1000000)*100, 
                  K=(raw$K/1000000)*100,
                  Na=(raw$Na/1000000)*100,
                  Fe=(raw$Fe/1000000)*100
                 ))

#########################################################################################################
#Figure 1 in Ebel et al. Body composition 

#subset by life stage
adult.d<-subset(dry1, ls=="1")
kelt.d<-subset(dry1, ls=="2")
smolt.d<-subset(dry1, ls=="3")


#Make jitter plot of % dry
options(scipen=10) # removes scientific notation from plots
x11(height=5.8, width=5.8)
par(mfrow=c(3,3))
par(oma=c(2,2,1,1)) #sets outer margins
par(mar=c(0.2,2,0.2,1.5))
par(las=1)
par(mgp=c(1, 1, 0))

#Plot %C dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$C, main="", xlab="", ylab="", cex.lab=1, cex.axis=1, cex=1, xlim=c(0,4), ylim=c(30, 65), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$C, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$C, pch=16, cex=1.25, col="black")


#plot %N dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$N, main="", xlab="", ylab="", cex.lab=1, cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(8,16), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$N, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$N, pch=16, cex=1.25, col="black")

#plot %P dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$P, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0,4), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$P, pch=8,  cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$P, pch=16, cex=1.25, col="black")

#Plot %Ca dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$Ca, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0, 6.5), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$Ca, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$Ca, pch=16, cex=1.25, col="black")

#Plot %S dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$S, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0.3, 1), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$S, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$S, pch=16, cex=1.25, col="black")

#Plot %K dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$K, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0.8, 1.8), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$K, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$K, pch=16, cex=1.25, col="black")

#Plot %Mg dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$Mg, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0.05, 0.18), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$Mg, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$Mg, pch=16, cex=1.25, col="black")

#Plot %Na dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$Na, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0, 1), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$Na, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$Na, pch=16, cex=1.25, col="black")

#Plot %Fe dry mass
plot(jitter(as.numeric(smolt.d$strm)), smolt.d$Fe, main="", xlab="", ylab="", cex.lab=1,  cex.axis=1, cex=1.25, xlim=c(0,4), ylim=c(0, 0.02), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt.d$strm)), kelt.d$Fe, pch=8, cex=1.25, col="black")
points(jitter(as.numeric(adult.d$strm)), adult.d$Fe, pch=16, cex=1.25, col="black")



#########################################

#Table of means and standard deviations for element concentrations by stream and life stage

#subset by life stage
adult.w<-subset(wet1, ls=="1")
kelt.w<-subset(wet1, ls=="2")
smolt.w<-subset(wet1, ls=="3")
#Subset each life stage by stream

cam.a<-subset(adult.d, strm=="1")
cam.k<-subset(kelt.d, strm=="1")
cam.s<-subset(smolt.d, strm=="1")

#Campbellton

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(cam.a$C); mat1[2,1]<-mean(cam.a$N); mat1[3,1]<-mean(cam.a$P); mat1[4,1]<-mean(cam.a$Ca); mat1[5,1]<-mean(cam.a$S); mat1[6,1]<-mean(cam.a$K); mat1[7,1]<-mean(cam.a$Mg); mat1[8,1]<-mean(cam.a$Na); mat1[9,1]<-mean(cam.a$Fe)
mat1[1,2]<-sd(cam.a$C); mat1[2,2]<-sd(cam.a$N); mat1[3,2]<-sd(cam.a$P); mat1[4,2]<-sd(cam.a$Ca); mat1[5,2]<-sd(cam.a$S); mat1[6,2]<-sd(cam.a$K); mat1[7,2]<-sd(cam.a$Mg); mat1[8,2]<-sd(cam.a$Na); mat1[9,2]<-sd(cam.a$Fe)

#kelt
mat1[1,3]<-mean(cam.k$C); mat1[2,3]<-mean(cam.k$N); mat1[3,3]<-mean(cam.k$P); mat1[4,3]<-mean(cam.k$Ca); mat1[5,3]<-mean(cam.k$S); mat1[6,3]<-mean(cam.k$K); mat1[7,3]<-mean(cam.k$Mg); mat1[8,3]<-mean(cam.k$Na); mat1[9,3]<-mean(cam.k$Fe)
mat1[1,4]<-sd(cam.k$C); mat1[2,4]<-sd(cam.k$N); mat1[3,4]<-sd(cam.k$P); mat1[4,4]<-sd(cam.k$Ca); mat1[5,4]<-sd(cam.k$S); mat1[6,4]<-sd(cam.k$K); mat1[7,4]<-sd(cam.k$Mg); mat1[8,4]<-sd(cam.k$Na); mat1[9,4]<-sd(cam.k$Fe)

#smolt
mat1[1,5]<-mean(cam.s$C); mat1[2,5]<-mean(cam.s$N); mat1[3,5]<-mean(cam.s$P); mat1[4,5]<-mean(cam.s$Ca); mat1[5,5]<-mean(cam.s$S); mat1[6,5]<-mean(cam.s$K); mat1[7,5]<-mean(cam.s$Mg); mat1[8,5]<-mean(cam.s$Na); mat1[9,5]<-mean(cam.s$Fe)
mat1[1,6]<-sd(cam.s$C); mat1[2,6]<-sd(cam.s$N); mat1[3,6]<-sd(cam.s$P); mat1[4,6]<-sd(cam.s$Ca); mat1[5,6]<-sd(cam.s$S); mat1[6,6]<-sd(cam.s$K); mat1[7,6]<-sd(cam.s$Mg); mat1[8,6]<-sd(cam.s$Na); mat1[9,6]<-sd(cam.s$Fe)

cam.conc<-mat1
rm(mat1)
###################################
#Conne

cn.a<-subset(adult.d, strm=="2")
cn.k<-subset(kelt.d, strm=="2")
cn.s<-subset(smolt.d, strm=="2")

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(cn.a$C); mat1[2,1]<-mean(cn.a$N); mat1[3,1]<-mean(cn.a$P); mat1[4,1]<-mean(cn.a$Ca); mat1[5,1]<-mean(cn.a$S); mat1[6,1]<-mean(cn.a$K); mat1[7,1]<-mean(cn.a$Mg); mat1[8,1]<-mean(cn.a$Na); mat1[9,1]<-mean(cn.a$Fe)
mat1[1,2]<-sd(cn.a$C); mat1[2,2]<-sd(cn.a$N); mat1[3,2]<-sd(cn.a$P); mat1[4,2]<-sd(cn.a$Ca); mat1[5,2]<-sd(cn.a$S); mat1[6,2]<-sd(cn.a$K); mat1[7,2]<-sd(cn.a$Mg); mat1[8,2]<-sd(cn.a$Na); mat1[9,2]<-sd(cn.a$Fe)

#kelt
mat1[1,3]<-mean(cn.k$C); mat1[2,3]<-mean(cn.k$N); mat1[3,3]<-mean(cn.k$P); mat1[4,3]<-mean(cn.k$Ca); mat1[5,3]<-mean(cn.k$S); mat1[6,3]<-mean(cn.k$K); mat1[7,3]<-mean(cn.k$Mg); mat1[8,3]<-mean(cn.k$Na); mat1[9,3]<-mean(cn.k$Fe)
mat1[1,4]<-sd(cn.k$C); mat1[2,4]<-sd(cn.k$N); mat1[3,4]<-sd(cn.k$P); mat1[4,4]<-sd(cn.k$Ca); mat1[5,4]<-sd(cn.k$S); mat1[6,4]<-sd(cn.k$K); mat1[7,4]<-sd(cn.k$Mg); mat1[8,4]<-sd(cn.k$Na); mat1[9,4]<-sd(cn.k$Fe)

#smolt
mat1[1,5]<-mean(cn.s$C); mat1[2,5]<-mean(cn.s$N); mat1[3,5]<-mean(cn.s$P); mat1[4,5]<-mean(cn.s$Ca); mat1[5,5]<-mean(cn.s$S); mat1[6,5]<-mean(cn.s$K); mat1[7,5]<-mean(cn.s$Mg); mat1[8,5]<-mean(cn.s$Na); mat1[9,5]<-mean(cn.s$Fe)
mat1[1,6]<-sd(cn.s$C); mat1[2,6]<-sd(cn.s$N); mat1[3,6]<-sd(cn.s$P); mat1[4,6]<-sd(cn.s$Ca); mat1[5,6]<-sd(cn.s$S); mat1[6,6]<-sd(cn.s$K); mat1[7,6]<-sd(cn.s$Mg); mat1[8,6]<-sd(cn.s$Na); mat1[9,6]<-sd(cn.s$Fe)

cn.conc<-mat1
rm(mat1)

############################################
#Western Arm

wab.a<-subset(adult.d, strm=="3")
wab.k<-subset(kelt.d, strm=="3")
wab.s<-subset(smolt.d, strm=="3")

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(wab.a$C); mat1[2,1]<-mean(wab.a$N); mat1[3,1]<-mean(wab.a$P); mat1[4,1]<-mean(wab.a$Ca); mat1[5,1]<-mean(wab.a$S); mat1[6,1]<-mean(wab.a$K); mat1[7,1]<-mean(wab.a$Mg); mat1[8,1]<-mean(wab.a$Na); mat1[9,1]<-mean(wab.a$Fe)
mat1[1,2]<-sd(wab.a$C); mat1[2,2]<-sd(wab.a$N); mat1[3,2]<-sd(wab.a$P); mat1[4,2]<-sd(wab.a$Ca); mat1[5,2]<-sd(wab.a$S); mat1[6,2]<-sd(wab.a$K); mat1[7,2]<-sd(wab.a$Mg); mat1[8,2]<-sd(wab.a$Na); mat1[9,2]<-sd(wab.a$Fe)

#kelt
mat1[1,3]<-mean(wab.k$C); mat1[2,3]<-mean(wab.k$N); mat1[3,3]<-mean(wab.k$P); mat1[4,3]<-mean(wab.k$Ca); mat1[5,3]<-mean(wab.k$S); mat1[6,3]<-mean(wab.k$K); mat1[7,3]<-mean(wab.k$Mg); mat1[8,3]<-mean(wab.k$Na); mat1[9,3]<-mean(wab.k$Fe)
mat1[1,4]<-sd(wab.k$C); mat1[2,4]<-sd(wab.k$N); mat1[3,4]<-sd(wab.k$P); mat1[4,4]<-sd(wab.k$Ca); mat1[5,4]<-sd(wab.k$S); mat1[6,4]<-sd(wab.k$K); mat1[7,4]<-sd(wab.k$Mg); mat1[8,4]<-sd(wab.k$Na); mat1[9,4]<-sd(wab.k$Fe)

#smolt
mat1[1,5]<-mean(wab.s$C); mat1[2,5]<-mean(wab.s$N); mat1[3,5]<-mean(wab.s$P); mat1[4,5]<-mean(wab.s$Ca); mat1[5,5]<-mean(wab.s$S); mat1[6,5]<-mean(wab.s$K); mat1[7,5]<-mean(wab.s$Mg); mat1[8,5]<-mean(wab.s$Na); mat1[9,5]<-mean(wab.s$Fe)
mat1[1,6]<-sd(wab.s$C); mat1[2,6]<-sd(wab.s$N); mat1[3,6]<-sd(wab.s$P); mat1[4,6]<-sd(wab.s$Ca); mat1[5,6]<-sd(wab.s$S); mat1[6,6]<-sd(wab.s$K); mat1[7,6]<-sd(wab.s$Mg); mat1[8,6]<-sd(wab.s$Na); mat1[9,6]<-sd(wab.s$Fe)

wab.conc<-mat1
rm(mat1)

#################################################################
################################################################
#################################################################


#% Element by WET WEIGHT 

#Table of means and standard deviations for element concentrations by stream and life stage

#subset by life stage
adult.w<-subset(wet1, ls=="1")
kelt.w<-subset(wet1, ls=="2")
smolt.w<-subset(wet1, ls=="3")

#Subset each life stage by stream

cam.a<-subset(adult.w, strm=="1")
cam.k<-subset(kelt.w, strm=="1")
cam.s<-subset(smolt.w, strm=="1")

#Campbellton

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(cam.a$C); mat1[2,1]<-mean(cam.a$N); mat1[3,1]<-mean(cam.a$P); mat1[4,1]<-mean(cam.a$Ca); mat1[5,1]<-mean(cam.a$S); mat1[6,1]<-mean(cam.a$K); mat1[7,1]<-mean(cam.a$Mg); mat1[8,1]<-mean(cam.a$Na); mat1[9,1]<-mean(cam.a$Fe)
mat1[1,2]<-sd(cam.a$C); mat1[2,2]<-sd(cam.a$N); mat1[3,2]<-sd(cam.a$P); mat1[4,2]<-sd(cam.a$Ca); mat1[5,2]<-sd(cam.a$S); mat1[6,2]<-sd(cam.a$K); mat1[7,2]<-sd(cam.a$Mg); mat1[8,2]<-sd(cam.a$Na); mat1[9,2]<-sd(cam.a$Fe)

#kelt
mat1[1,3]<-mean(cam.k$C); mat1[2,3]<-mean(cam.k$N); mat1[3,3]<-mean(cam.k$P); mat1[4,3]<-mean(cam.k$Ca); mat1[5,3]<-mean(cam.k$S); mat1[6,3]<-mean(cam.k$K); mat1[7,3]<-mean(cam.k$Mg); mat1[8,3]<-mean(cam.k$Na); mat1[9,3]<-mean(cam.k$Fe)
mat1[1,4]<-sd(cam.k$C); mat1[2,4]<-sd(cam.k$N); mat1[3,4]<-sd(cam.k$P); mat1[4,4]<-sd(cam.k$Ca); mat1[5,4]<-sd(cam.k$S); mat1[6,4]<-sd(cam.k$K); mat1[7,4]<-sd(cam.k$Mg); mat1[8,4]<-sd(cam.k$Na); mat1[9,4]<-sd(cam.k$Fe)

#smolt
mat1[1,5]<-mean(cam.s$C); mat1[2,5]<-mean(cam.s$N); mat1[3,5]<-mean(cam.s$P); mat1[4,5]<-mean(cam.s$Ca); mat1[5,5]<-mean(cam.s$S); mat1[6,5]<-mean(cam.s$K); mat1[7,5]<-mean(cam.s$Mg); mat1[8,5]<-mean(cam.s$Na); mat1[9,5]<-mean(cam.s$Fe)
mat1[1,6]<-sd(cam.s$C); mat1[2,6]<-sd(cam.s$N); mat1[3,6]<-sd(cam.s$P); mat1[4,6]<-sd(cam.s$Ca); mat1[5,6]<-sd(cam.s$S); mat1[6,6]<-sd(cam.s$K); mat1[7,6]<-sd(cam.s$Mg); mat1[8,6]<-sd(cam.s$Na); mat1[9,6]<-sd(cam.s$Fe)

cam.conc<-mat1
rm(mat1)
###################################
#Conne

cn.a<-subset(adult.w, strm=="2")
cn.k<-subset(kelt.w, strm=="2")
cn.s<-subset(smolt.w, strm=="2")

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(cn.a$C); mat1[2,1]<-mean(cn.a$N); mat1[3,1]<-mean(cn.a$P); mat1[4,1]<-mean(cn.a$Ca); mat1[5,1]<-mean(cn.a$S); mat1[6,1]<-mean(cn.a$K); mat1[7,1]<-mean(cn.a$Mg); mat1[8,1]<-mean(cn.a$Na); mat1[9,1]<-mean(cn.a$Fe)
mat1[1,2]<-sd(cn.a$C); mat1[2,2]<-sd(cn.a$N); mat1[3,2]<-sd(cn.a$P); mat1[4,2]<-sd(cn.a$Ca); mat1[5,2]<-sd(cn.a$S); mat1[6,2]<-sd(cn.a$K); mat1[7,2]<-sd(cn.a$Mg); mat1[8,2]<-sd(cn.a$Na); mat1[9,2]<-sd(cn.a$Fe)

#kelt
mat1[1,3]<-mean(cn.k$C); mat1[2,3]<-mean(cn.k$N); mat1[3,3]<-mean(cn.k$P); mat1[4,3]<-mean(cn.k$Ca); mat1[5,3]<-mean(cn.k$S); mat1[6,3]<-mean(cn.k$K); mat1[7,3]<-mean(cn.k$Mg); mat1[8,3]<-mean(cn.k$Na); mat1[9,3]<-mean(cn.k$Fe)
mat1[1,4]<-sd(cn.k$C); mat1[2,4]<-sd(cn.k$N); mat1[3,4]<-sd(cn.k$P); mat1[4,4]<-sd(cn.k$Ca); mat1[5,4]<-sd(cn.k$S); mat1[6,4]<-sd(cn.k$K); mat1[7,4]<-sd(cn.k$Mg); mat1[8,4]<-sd(cn.k$Na); mat1[9,4]<-sd(cn.k$Fe)

#smolt
mat1[1,5]<-mean(cn.s$C); mat1[2,5]<-mean(cn.s$N); mat1[3,5]<-mean(cn.s$P); mat1[4,5]<-mean(cn.s$Ca); mat1[5,5]<-mean(cn.s$S); mat1[6,5]<-mean(cn.s$K); mat1[7,5]<-mean(cn.s$Mg); mat1[8,5]<-mean(cn.s$Na); mat1[9,5]<-mean(cn.s$Fe)
mat1[1,6]<-sd(cn.s$C); mat1[2,6]<-sd(cn.s$N); mat1[3,6]<-sd(cn.s$P); mat1[4,6]<-sd(cn.s$Ca); mat1[5,6]<-sd(cn.s$S); mat1[6,6]<-sd(cn.s$K); mat1[7,6]<-sd(cn.s$Mg); mat1[8,6]<-sd(cn.s$Na); mat1[9,6]<-sd(cn.s$Fe)

cn.conc<-mat1
rm(mat1)

############################################
#Western Arm

wab.a<-subset(adult.w, strm=="3")
wab.k<-subset(kelt.w, strm=="3")
wab.s<-subset(smolt.w, strm=="3")

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(wab.a$C); mat1[2,1]<-mean(wab.a$N); mat1[3,1]<-mean(wab.a$P); mat1[4,1]<-mean(wab.a$Ca); mat1[5,1]<-mean(wab.a$S); mat1[6,1]<-mean(wab.a$K); mat1[7,1]<-mean(wab.a$Mg); mat1[8,1]<-mean(wab.a$Na); mat1[9,1]<-mean(wab.a$Fe)
mat1[1,2]<-sd(wab.a$C); mat1[2,2]<-sd(wab.a$N); mat1[3,2]<-sd(wab.a$P); mat1[4,2]<-sd(wab.a$Ca); mat1[5,2]<-sd(wab.a$S); mat1[6,2]<-sd(wab.a$K); mat1[7,2]<-sd(wab.a$Mg); mat1[8,2]<-sd(wab.a$Na); mat1[9,2]<-sd(wab.a$Fe)

#kelt
mat1[1,3]<-mean(wab.k$C); mat1[2,3]<-mean(wab.k$N); mat1[3,3]<-mean(wab.k$P); mat1[4,3]<-mean(wab.k$Ca); mat1[5,3]<-mean(wab.k$S); mat1[6,3]<-mean(wab.k$K); mat1[7,3]<-mean(wab.k$Mg); mat1[8,3]<-mean(wab.k$Na); mat1[9,3]<-mean(wab.k$Fe)
mat1[1,4]<-sd(wab.k$C); mat1[2,4]<-sd(wab.k$N); mat1[3,4]<-sd(wab.k$P); mat1[4,4]<-sd(wab.k$Ca); mat1[5,4]<-sd(wab.k$S); mat1[6,4]<-sd(wab.k$K); mat1[7,4]<-sd(wab.k$Mg); mat1[8,4]<-sd(wab.k$Na); mat1[9,4]<-sd(wab.k$Fe)

#smolt
mat1[1,5]<-mean(wab.s$C); mat1[2,5]<-mean(wab.s$N); mat1[3,5]<-mean(wab.s$P); mat1[4,5]<-mean(wab.s$Ca); mat1[5,5]<-mean(wab.s$S); mat1[6,5]<-mean(wab.s$K); mat1[7,5]<-mean(wab.s$Mg); mat1[8,5]<-mean(wab.s$Na); mat1[9,5]<-mean(wab.s$Fe)
mat1[1,6]<-sd(wab.s$C); mat1[2,6]<-sd(wab.s$N); mat1[3,6]<-sd(wab.s$P); mat1[4,6]<-sd(wab.s$Ca); mat1[5,6]<-sd(wab.s$S); mat1[6,6]<-sd(wab.s$K); mat1[7,6]<-sd(wab.s$Mg); mat1[8,6]<-sd(wab.s$Na); mat1[9,6]<-sd(wab.s$Fe)

wab.conc<-mat1
rm(mat1)

write.table(wab.conc)
write.table(cn.conc)
write.table(cam.conc)

#################################################################
#POOLED MEANS

mat1<-matrix(nrow=9, ncol=6)
colnames(mat1)<-c("adult","sd", "kelt", "sd", "smolt", "sd")
rownames(mat1)<-c("C", "N", "P", "Ca", "S", "K", "Mg", "Na", "Fe")
#adult
mat1[1,1]<-mean(adult.w$C); mat1[2,1]<-mean(adult.w$N); mat1[3,1]<-mean(adult.w$P); mat1[4,1]<-mean(adult.w$Ca); mat1[5,1]<-mean(adult.w$S); mat1[6,1]<-mean(adult.w$K); mat1[7,1]<-mean(adult.w$Mg); mat1[8,1]<-mean(adult.w$Na); mat1[9,1]<-mean(adult.w$Fe)
mat1[1,2]<-sd(adult.w$C); mat1[2,2]<-sd(adult.w$N); mat1[3,2]<-sd(adult.w$P); mat1[4,2]<-sd(adult.w$Ca); mat1[5,2]<-sd(adult.w$S); mat1[6,2]<-sd(adult.w$K); mat1[7,2]<-sd(adult.w$Mg); mat1[8,2]<-sd(adult.w$Na); mat1[9,2]<-sd(adult.w$Fe)

#kelt
mat1[1,3]<-mean(kelt.w$C); mat1[2,3]<-mean(kelt.w$N); mat1[3,3]<-mean(kelt.w$P); mat1[4,3]<-mean(kelt.w$Ca); mat1[5,3]<-mean(kelt.w$S); mat1[6,3]<-mean(kelt.w$K); mat1[7,3]<-mean(kelt.w$Mg); mat1[8,3]<-mean(kelt.w$Na); mat1[9,3]<-mean(kelt.w$Fe)
mat1[1,4]<-sd(kelt.w$C); mat1[2,4]<-sd(kelt.w$N); mat1[3,4]<-sd(kelt.w$P); mat1[4,4]<-sd(kelt.w$Ca); mat1[5,4]<-sd(kelt.w$S); mat1[6,4]<-sd(kelt.w$K); mat1[7,4]<-sd(kelt.w$Mg); mat1[8,4]<-sd(kelt.w$Na); mat1[9,4]<-sd(kelt.w$Fe)

#smolt
mat1[1,5]<-mean(smolt.w$C); mat1[2,5]<-mean(smolt.w$N); mat1[3,5]<-mean(smolt.w$P); mat1[4,5]<-mean(smolt.w$Ca); mat1[5,5]<-mean(smolt.w$S); mat1[6,5]<-mean(smolt.w$K); mat1[7,5]<-mean(smolt.w$Mg); mat1[8,5]<-mean(smolt.w$Na); mat1[9,5]<-mean(smolt.w$Fe)
mat1[1,6]<-sd(smolt.w$C); mat1[2,6]<-sd(smolt.w$N); mat1[3,6]<-sd(smolt.w$P); mat1[4,6]<-sd(smolt.w$Ca); mat1[5,6]<-sd(smolt.w$S); mat1[6,6]<-sd(smolt.w$K); mat1[7,6]<-sd(smolt.w$Mg); mat1[8,6]<-sd(smolt.w$Na); mat1[9,6]<-sd(smolt.w$Fe)

mean.conc<-mat1
rm(mat1)

write.table(mean.conc)

mean(adult.w$dw.1)
sd(adult.w$dw.1)

mean(kelt.w$dw.1)
sd(kelt.w$dw.1)

mean(smolt.w$dw.1)
sd(smolt.w$dw.1)
###############################################################################
##############################################################
#General linear models for testing whether life stage explains variation in Atlantic salmon elemental composition

require(AICcmodavg)
#CARBON

Cand.models<-list()
Cand.models[[1]]<-glm(C~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(C~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(C~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(C~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(C~1, family = gaussian, data=dry1)
GLM2<-glm(C~ls, family = gaussian, data=dry1)
GLM3<-glm(C~strm, family=gaussian, data=dry1)
GLM4<-glm(C~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

c.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

###############################################################################################
#Nitrogen
Cand.models<-list()
Cand.models[[1]]<-glm(N~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(N~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(N~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(N~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(N~1, family = gaussian, data=dry1)
GLM2<-glm(N~ls, family = gaussian, data=dry1)
GLM3<-glm(N~strm, family=gaussian, data=dry1)
GLM4<-glm(N~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

n.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

#######################################################################################

#Phosphorus
Cand.models<-list()
Cand.models[[1]]<-glm(P~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(P~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(P~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(P~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(P~1, family = gaussian, data=dry1)
GLM2<-glm(P~ls, family = gaussian, data=dry1)
GLM3<-glm(P~strm, family=gaussian, data=dry1)
GLM4<-glm(P~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

p.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)
###########################################################################

#Calcium
Cand.models<-list()
Cand.models[[1]]<-glm(Ca~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(Ca~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(Ca~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(Ca~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(Ca~1, family = gaussian, data=dry1)
GLM2<-glm(Ca~ls, family = gaussian, data=dry1)
GLM3<-glm(Ca~strm, family=gaussian, data=dry1)
GLM4<-glm(Ca~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

ca.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

###############################################################################################

#Sulfur

Cand.models<-list()
Cand.models[[1]]<-glm(S~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(S~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(S~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(S~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(S~1, family = gaussian, data=dry1)
GLM2<-glm(S~ls, family = gaussian, data=dry1)
GLM3<-glm(S~strm, family=gaussian, data=dry1)
GLM4<-glm(S~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

s.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

###################################################################################################

#Potassium

Cand.models<-list()
Cand.models[[1]]<-glm(K~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(K~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(K~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(K~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(K~1, family = gaussian, data=dry1)
GLM2<-glm(K~ls, family = gaussian, data=dry1)
GLM3<-glm(K~strm, family=gaussian, data=dry1)
GLM4<-glm(K~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

k.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

##########################################################################################

#Magnesium
Cand.models<-list()
Cand.models[[1]]<-glm(Mg~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(Mg~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(Mg~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(Mg~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(Mg~1, family = gaussian, data=dry1)
GLM2<-glm(Mg~ls, family = gaussian, data=dry1)
GLM3<-glm(Mg~strm, family=gaussian, data=dry1)
GLM4<-glm(Mg~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

mg.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

################################################################################################

Cand.models<-list()
Cand.models[[1]]<-glm(Na~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(Na~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(Na~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(Na~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(Na~1, family = gaussian, data=dry1)
GLM2<-glm(Na~ls, family = gaussian, data=dry1)
GLM3<-glm(Na~strm, family=gaussian, data=dry1)
GLM4<-glm(Na~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

na.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)

#########################################################################################

#Iron

Cand.models<-list()
Cand.models[[1]]<-glm(Fe~1 , family=gaussian, data=dry1)
Cand.models[[2]]<-glm(Fe~ls, family=gaussian, data=dry1)
Cand.models[[3]]<-glm(Fe~strm, family=gaussian, data=dry1)
Cand.models[[4]]<-glm(Fe~ls*strm, family=gaussian, data=dry1)

Modnames<-c("intercept", "life.stage", "river", "life.stage.river")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

GLM1<-glm(Fe~1, family = gaussian, data=dry1)
GLM2<-glm(Fe~ls, family = gaussian, data=dry1)
GLM3<-glm(Fe~strm, family=gaussian, data=dry1)
GLM4<-glm(Fe~ls*strm, family=gaussian, data=dry1)

output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("Intercept", "ls", "strm", "ls*strm")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM1))
output[2,1]<-(AIC(GLM2))
output[3,1]<-(AIC(GLM3))
output[4,1]<-(AIC(GLM4))
#Extract Deviance explained

output[1,2]<-((GLM1$null.deviance-GLM1$deviance)/GLM1$null.deviance)*100
output[2,2]<-((GLM2$null.deviance-GLM2$deviance)/GLM2$null.deviance)*100
output[3,2]<-((GLM3$null.deviance-GLM3$deviance)/GLM3$null.deviance)*100
output[4,2]<-((GLM4$null.deviance-GLM4$deviance)/GLM4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM1)[1]
output[2,3]<-logLik(GLM2)[1]
output[3,3]<-logLik(GLM3)[1]
output[4,3]<-logLik(GLM4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM1) - min(output[,1])
output[2,4]<-AIC(GLM2) - min(output[,1])
output[3,4]<-AIC(GLM3) - min(output[,1])
output[4,4]<-AIC(GLM4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

fe.glm.output<-output

rm(GLM1); rm(GLM2); rm(GLM3); rm(GLM4); rm(Cand.models); rm(output)
###########################################################################################################




#JFB FIGURE 2. 


#Make figures for effect sizes for each element - life stage combination 

#Subset dataframe dry1 into life stages
ad<-subset(dry1, ls=="1")
sm<-subset(dry1, ls=="2")
kt<-subset(dry1, ls=="3")

#Make dataframe of life-stage perc difference

#The concentration of Element X is A% higher/lower in smolts than it is in adults

mat1<-matrix(nrow=9, ncol=2) #smult vs. adult
colnames(mat1)<-c("element","perc.diff")
#smd elements
mat1[1,1]<-9; mat1[2,1]<-8; mat1[3,1]<-7; mat1[4,1]<-6; mat1[5,1]<-5; mat1[6,1]<-4; mat1[7,1]<-3; mat1[8,1]<-2; mat1[9,1]<-1

#Insert percent differences
mat1[1,2]<-((mean(ad$C)-mean(sm$C))/mean(ad$C))*100
mat1[2,2]<-((mean(ad$N)-mean(sm$N))/mean(ad$N))*100
mat1[3,2]<-((mean(ad$P)-mean(sm$P))/mean(ad$P))*100
mat1[4,2]<-((mean(ad$Ca)-mean(sm$Ca))/mean(ad$Ca))*100
mat1[5,2]<-((mean(ad$S)-mean(sm$S))/mean(ad$S))*100
mat1[6,2]<-((mean(ad$K)-mean(sm$K))/mean(ad$K))*100
mat1[7,2]<-((mean(ad$Mg)-mean(sm$Mg))/mean(ad$Mg))*100
mat1[8,2]<-((mean(ad$Na)-mean(sm$Na))/mean(ad$Na))*100
mat1[9,2]<-((mean(ad$Fe)-mean(sm$Fe))/mean(ad$Fe))*100

mat1

#The concentration of Element X is A% higher/lower in adults than it is in kelts


mat2<-matrix(nrow=9, ncol=2) #adult vs. kelt
colnames(mat2)<-c("element","perc.diff")
#add elements
mat2[1,1]<-9; mat2[2,1]<-8; mat2[3,1]<-7; mat2[4,1]<-6; mat2[5,1]<-5; mat2[6,1]<-4; mat2[7,1]<-3; mat2[8,1]<-2; mat2[9,1]<-1

#Insert percent differences
mat2[1,2]<-((mean(ad$C)-mean(kt$C))/mean(ad$C))*100
mat2[2,2]<-((mean(ad$N)-mean(kt$N))/mean(ad$N))*100
mat2[3,2]<-((mean(ad$P)-mean(kt$P))/mean(ad$P))*100
mat2[4,2]<-((mean(ad$Ca)-mean(kt$Ca))/mean(ad$Ca))*100
mat2[5,2]<-((mean(ad$S)-mean(kt$S))/mean(ad$S))*100
mat2[6,2]<-((mean(ad$K)-mean(kt$K))/mean(ad$K))*100
mat2[7,2]<-((mean(ad$Mg)-mean(kt$Mg))/mean(ad$Mg))*100
mat2[8,2]<-((mean(ad$Na)-mean(kt$Na))/mean(ad$Na))*100
mat2[9,2]<-((mean(ad$Fe)-mean(kt$Fe))/mean(ad$Fe))*100

mat2
#The concentration of Element X is A% higher/lower in kelts than it is in smolts

mat3<-matrix(nrow=9, ncol=2) #ktult vs. kelt
colnames(mat3)<-c("element","perc.diff")
#elements
mat3[1,1]<-9; mat3[2,1]<-8; mat3[3,1]<-7; mat3[4,1]<-6; mat3[5,1]<-5; mat3[6,1]<-4; mat3[7,1]<-3; mat3[8,1]<-2; mat3[9,1]<-1

#Insert percent differences
mat3[1,2]<-((mean(kt$C)-mean(sm$C))/mean(kt$C))*100
mat3[2,2]<-((mean(kt$N)-mean(sm$N))/mean(kt$N))*100
mat3[3,2]<-((mean(kt$P)-mean(sm$P))/mean(kt$P))*100
mat3[4,2]<-((mean(kt$Ca)-mean(sm$Ca))/mean(kt$Ca))*100
mat3[5,2]<-((mean(kt$S)-mean(sm$S))/mean(kt$S))*100
mat3[6,2]<-((mean(kt$K)-mean(sm$K))/mean(kt$K))*100
mat3[7,2]<-((mean(kt$Mg)-mean(sm$Mg))/mean(kt$Mg))*100
mat3[8,2]<-((mean(kt$Na)-mean(sm$Na))/mean(kt$Na))*100
mat3[9,2]<-((mean(kt$Fe)-mean(sm$Fe))/mean(kt$Fe))*100

mat3


#Transform all matrices to data frames so that they can be easily imported into other codes
avs<-as.data.frame(mat1)
avk<-as.data.frame(mat2)
kvs<-as.data.frame(mat3)
##########################

################################################################

###Make confidence intervals on % difference between means using a simple loop


avk.p<-NULL
avk.p<-data.frame(y=kt$P)
avk.p$x1<-sapply(ad$P[1], function(x)((x-kt$P)/x))
avk.p$x2<-sapply(ad$P[2], function(x)((x-kt$P)/x))
avk.p$x3<-sapply(ad$P[3], function(x)((x-kt$P)/x))                      
avk.p$x4<-sapply(ad$P[4], function(x)((x-kt$P)/x))             
avk.p$x5<-sapply(ad$P[5], function(x)((x-kt$P)/x))                      
avk.p$x6<-sapply(ad$P[6], function(x)((x-kt$P)/x))                      
avk.p$x7<-sapply(ad$P[7], function(x)((x-kt$P)/x))                      
avk.p$x8<-sapply(ad$P[8], function(x)((x-kt$P)/x))                      
avk.p$x9<-sapply(ad$P[9], function(x)((x-kt$P)/x)) 
avk.p$x10<-sapply(ad$P[10], function(x)((x-kt$P)/x)) 
avk.p$x11<-sapply(ad$P[11], function(x)((x-kt$P)/x)) 
avk.p$x12<-sapply(ad$P[12], function(x)((x-kt$P)/x)) 
avk.p$x13<-sapply(ad$P[13], function(x)((x-kt$P)/x)) 
avk.p$x14<-sapply(ad$P[14], function(x)((x-kt$P)/x)) 

#make dataframe to hold all combinations for all elements
avk.a<-NULL
avk.a<-data.frame(P=rbind(avk.p$x1, avk.p$x2, avk.p$x3, avk.p$x4, avk.p$x5, avk.p$x6, avk.p$x7, avk.p$x7, avk.p$x8, avk.p$x9, avk.p$x10, avk.p$x11, avk.p$x12, avk.p$x13, avk.p$x14))
avk.P<-sort(avk.a$P, decreasing=F)                      
#Then 255*0.975 = 249, so the upper limit is 6 backwards from the highest value, so -0.84
#Lower limit is 255*0.025 = 6, so 6 forwards from lowest value is -2.53


avk.c<-NULL
avk.c<-data.frame(y=kt$C)
avk.c$x1<-sapply(ad$C[1], function(x)((x-kt$C)/x))
avk.c$x2<-sapply(ad$C[2], function(x)((x-kt$C)/x))
avk.c$x3<-sapply(ad$C[3], function(x)((x-kt$C)/x))                      
avk.c$x4<-sapply(ad$C[4], function(x)((x-kt$C)/x))             
avk.c$x5<-sapply(ad$C[5], function(x)((x-kt$C)/x))                      
avk.c$x6<-sapply(ad$C[6], function(x)((x-kt$C)/x))                      
avk.c$x7<-sapply(ad$C[7], function(x)((x-kt$C)/x))                      
avk.c$x8<-sapply(ad$C[8], function(x)((x-kt$C)/x))                      
avk.c$x9<-sapply(ad$C[9], function(x)((x-kt$C)/x)) 
avk.c$x10<-sapply(ad$C[10], function(x)((x-kt$C)/x)) 
avk.c$x11<-sapply(ad$C[11], function(x)((x-kt$C)/x)) 
avk.c$x12<-sapply(ad$C[12], function(x)((x-kt$C)/x)) 
avk.c$x13<-sapply(ad$C[13], function(x)((x-kt$C)/x)) 
avk.c$x14<-sapply(ad$C[14], function(x)((x-kt$C)/x)) 

avk.a$C<-rbind(avk.c$x1, avk.c$x2, avk.c$x3, avk.c$x4, avk.c$x5, avk.c$x6, avk.c$x7, avk.c$x7, avk.c$x8, avk.c$x9, avk.c$x10, avk.c$x11, avk.c$x12, avk.c$x13, avk.c$x14)
avk.C<-sort(avk.a$C, decreasing=F)   
#Nitrogen
avk.n<-NULL
avk.n<-data.frame(y=kt$N)
avk.n$x1<-sapply(ad$N[1], function(x)((x-kt$N)/x))
avk.n$x2<-sapply(ad$N[2], function(x)((x-kt$N)/x))
avk.n$x3<-sapply(ad$N[3], function(x)((x-kt$N)/x))                      
avk.n$x4<-sapply(ad$N[4], function(x)((x-kt$N)/x))             
avk.n$x5<-sapply(ad$N[5], function(x)((x-kt$N)/x))                      
avk.n$x6<-sapply(ad$N[6], function(x)((x-kt$N)/x))                      
avk.n$x7<-sapply(ad$N[7], function(x)((x-kt$N)/x))                      
avk.n$x8<-sapply(ad$N[8], function(x)((x-kt$N)/x))                      
avk.n$x9<-sapply(ad$N[9], function(x)((x-kt$N)/x)) 
avk.n$x10<-sapply(ad$N[10], function(x)((x-kt$N)/x)) 
avk.n$x11<-sapply(ad$N[11], function(x)((x-kt$N)/x)) 
avk.n$x12<-sapply(ad$N[12], function(x)((x-kt$N)/x)) 
avk.n$x13<-sapply(ad$N[13], function(x)((x-kt$N)/x)) 
avk.n$x14<-sapply(ad$N[14], function(x)((x-kt$N)/x)) 

avk.a$N<-rbind(avk.n$x1, avk.n$x2, avk.n$x3, avk.n$x4, avk.n$x5, avk.n$x6, avk.n$x7, avk.n$x7, avk.n$x8, avk.n$x9, avk.n$x10, avk.n$x11, avk.n$x12, avk.n$x13, avk.n$x14)
avk.N<-sort(avk.a$N, decreasing=F)  


#Calcium
avk.ca<-NULL
avk.ca<-data.frame(y=kt$Ca)
avk.ca$x1<-sapply(ad$Ca[1], function(x)((x-kt$Ca)/x))
avk.ca$x2<-sapply(ad$Ca[2], function(x)((x-kt$Ca)/x))
avk.ca$x3<-sapply(ad$Ca[3], function(x)((x-kt$Ca)/x))                      
avk.ca$x4<-sapply(ad$Ca[4], function(x)((x-kt$Ca)/x))             
avk.ca$x5<-sapply(ad$Ca[5], function(x)((x-kt$Ca)/x))                      
avk.ca$x6<-sapply(ad$Ca[6], function(x)((x-kt$Ca)/x))                      
avk.ca$x7<-sapply(ad$Ca[7], function(x)((x-kt$Ca)/x))                      
avk.ca$x8<-sapply(ad$Ca[8], function(x)((x-kt$Ca)/x))                      
avk.ca$x9<-sapply(ad$Ca[9], function(x)((x-kt$Ca)/x)) 
avk.ca$x10<-sapply(ad$Ca[10], function(x)((x-kt$Ca)/x)) 
avk.ca$x11<-sapply(ad$Ca[11], function(x)((x-kt$Ca)/x)) 
avk.ca$x12<-sapply(ad$Ca[12], function(x)((x-kt$Ca)/x)) 
avk.ca$x13<-sapply(ad$Ca[13], function(x)((x-kt$Ca)/x)) 
avk.ca$x14<-sapply(ad$Ca[14], function(x)((x-kt$Ca)/x)) 

avk.a$Ca<-rbind(avk.ca$x1, avk.ca$x2, avk.ca$x3, avk.ca$x4, avk.ca$x5, avk.ca$x6, avk.ca$x7, avk.ca$x7, avk.ca$x8, avk.ca$x9, avk.ca$x10, avk.ca$x11, avk.ca$x12, avk.ca$x13, avk.ca$x14)
avk.Ca<-sort(avk.a$Ca, decreasing=F) 
###########################################################################

#Sulfur
avk.s<-NULL
avk.s<-data.frame(y=kt$S)
avk.s$x1<-sapply(ad$S[1], function(x)((x-kt$S)/x))
avk.s$x2<-sapply(ad$S[2], function(x)((x-kt$S)/x))
avk.s$x3<-sapply(ad$S[3], function(x)((x-kt$S)/x))                      
avk.s$x4<-sapply(ad$S[4], function(x)((x-kt$S)/x))             
avk.s$x5<-sapply(ad$S[5], function(x)((x-kt$S)/x))                      
avk.s$x6<-sapply(ad$S[6], function(x)((x-kt$S)/x))                      
avk.s$x7<-sapply(ad$S[7], function(x)((x-kt$S)/x))                      
avk.s$x8<-sapply(ad$S[8], function(x)((x-kt$S)/x))                      
avk.s$x9<-sapply(ad$S[9], function(x)((x-kt$S)/x)) 
avk.s$x10<-sapply(ad$S[10], function(x)((x-kt$S)/x)) 
avk.s$x11<-sapply(ad$S[11], function(x)((x-kt$S)/x)) 
avk.s$x12<-sapply(ad$S[12], function(x)((x-kt$S)/x)) 
avk.s$x13<-sapply(ad$S[13], function(x)((x-kt$S)/x)) 
avk.s$x14<-sapply(ad$S[14], function(x)((x-kt$S)/x)) 

avk.a$S<-rbind(avk.s$x1, avk.s$x2, avk.s$x3, avk.s$x4, avk.s$x5, avk.s$x6, avk.s$x7, avk.s$x7, avk.s$x8, avk.s$x9, avk.s$x10, avk.s$x11, avk.s$x12, avk.s$x13, avk.s$x14)
avk.S<-sort(avk.a$S, decreasing=F) 

####################################################################################

#Potassium
avk.k<-NULL
avk.k<-data.frame(y=kt$K)
avk.k$x1<-sapply(ad$K[1], function(x)((x-kt$K)/x))
avk.k$x2<-sapply(ad$K[2], function(x)((x-kt$K)/x))
avk.k$x3<-sapply(ad$K[3], function(x)((x-kt$K)/x))                      
avk.k$x4<-sapply(ad$K[4], function(x)((x-kt$K)/x))             
avk.k$x5<-sapply(ad$K[5], function(x)((x-kt$K)/x))                      
avk.k$x6<-sapply(ad$K[6], function(x)((x-kt$K)/x))                      
avk.k$x7<-sapply(ad$K[7], function(x)((x-kt$K)/x))                      
avk.k$x8<-sapply(ad$K[8], function(x)((x-kt$K)/x))                      
avk.k$x9<-sapply(ad$K[9], function(x)((x-kt$K)/x)) 
avk.k$x10<-sapply(ad$K[10], function(x)((x-kt$K)/x)) 
avk.k$x11<-sapply(ad$K[11], function(x)((x-kt$K)/x)) 
avk.k$x12<-sapply(ad$K[12], function(x)((x-kt$K)/x)) 
avk.k$x13<-sapply(ad$K[13], function(x)((x-kt$K)/x)) 
avk.k$x14<-sapply(ad$K[14], function(x)((x-kt$K)/x)) 

avk.a$K<-rbind(avk.k$x1, avk.k$x2, avk.k$x3, avk.k$x4, avk.k$x5, avk.k$x6, avk.k$x7, avk.k$x7, avk.k$x8, avk.k$x9, avk.k$x10, avk.k$x11, avk.k$x12, avk.k$x13, avk.k$x14)
avk.K<-sort(avk.a$K, decreasing=F) 

######################################################################
#Magnesium
avk.mg<-NULL
avk.mg<-data.frame(y=kt$Mg)
avk.mg$x1<-sapply(ad$Mg[1], function(x)((x-kt$Mg)/x))
avk.mg$x2<-sapply(ad$Mg[2], function(x)((x-kt$Mg)/x))
avk.mg$x3<-sapply(ad$Mg[3], function(x)((x-kt$Mg)/x))                      
avk.mg$x4<-sapply(ad$Mg[4], function(x)((x-kt$Mg)/x))             
avk.mg$x5<-sapply(ad$Mg[5], function(x)((x-kt$Mg)/x))                      
avk.mg$x6<-sapply(ad$Mg[6], function(x)((x-kt$Mg)/x))                      
avk.mg$x7<-sapply(ad$Mg[7], function(x)((x-kt$Mg)/x))                      
avk.mg$x8<-sapply(ad$Mg[8], function(x)((x-kt$Mg)/x))                      
avk.mg$x9<-sapply(ad$Mg[9], function(x)((x-kt$Mg)/x)) 
avk.mg$x10<-sapply(ad$Mg[10], function(x)((x-kt$Mg)/x)) 
avk.mg$x11<-sapply(ad$Mg[11], function(x)((x-kt$Mg)/x)) 
avk.mg$x12<-sapply(ad$Mg[12], function(x)((x-kt$Mg)/x)) 
avk.mg$x13<-sapply(ad$Mg[13], function(x)((x-kt$Mg)/x)) 
avk.mg$x14<-sapply(ad$Mg[14], function(x)((x-kt$Mg)/x)) 

avk.a$Mg<-rbind(avk.mg$x1, avk.mg$x2, avk.mg$x3, avk.mg$x4, avk.mg$x5, avk.mg$x6, avk.mg$x7, avk.mg$x7, avk.mg$x8, avk.mg$x9, avk.mg$x10, avk.mg$x11, avk.mg$x12, avk.mg$x13, avk.mg$x14)
avk.Mg<-sort(avk.a$Mg, decreasing=F) 

######################################################################
#Sodium
avk.na<-NULL
avk.na<-data.frame(y=kt$Na)
avk.na$x1<-sapply(ad$Na[1], function(x)((x-kt$Na)/x))
avk.na$x2<-sapply(ad$Na[2], function(x)((x-kt$Na)/x))
avk.na$x3<-sapply(ad$Na[3], function(x)((x-kt$Na)/x))                      
avk.na$x4<-sapply(ad$Na[4], function(x)((x-kt$Na)/x))             
avk.na$x5<-sapply(ad$Na[5], function(x)((x-kt$Na)/x))                      
avk.na$x6<-sapply(ad$Na[6], function(x)((x-kt$Na)/x))                      
avk.na$x7<-sapply(ad$Na[7], function(x)((x-kt$Na)/x))                      
avk.na$x8<-sapply(ad$Na[8], function(x)((x-kt$Na)/x))                      
avk.na$x9<-sapply(ad$Na[9], function(x)((x-kt$Na)/x)) 
avk.na$x10<-sapply(ad$Na[10], function(x)((x-kt$Na)/x)) 
avk.na$x11<-sapply(ad$Na[11], function(x)((x-kt$Na)/x)) 
avk.na$x12<-sapply(ad$Na[12], function(x)((x-kt$Na)/x)) 
avk.na$x13<-sapply(ad$Na[13], function(x)((x-kt$Na)/x)) 
avk.na$x14<-sapply(ad$Na[14], function(x)((x-kt$Na)/x)) 

avk.a$Na<-rbind(avk.na$x1, avk.na$x2, avk.na$x3, avk.na$x4, avk.na$x5, avk.na$x6, avk.na$x7, avk.na$x7, avk.na$x8, avk.na$x9, avk.na$x10, avk.na$x11, avk.na$x12, avk.na$x13, avk.na$x14)
avk.Na<-sort(avk.a$Na, decreasing=F) 


############################################################################################
#Iron

avk.fe<-NULL
avk.fe<-data.frame(y=kt$Fe)
avk.fe$x1<-sapply(ad$Fe[1], function(x)((x-kt$Fe)/x))
avk.fe$x2<-sapply(ad$Fe[2], function(x)((x-kt$Fe)/x))
avk.fe$x3<-sapply(ad$Fe[3], function(x)((x-kt$Fe)/x))                      
avk.fe$x4<-sapply(ad$Fe[4], function(x)((x-kt$Fe)/x))             
avk.fe$x5<-sapply(ad$Fe[5], function(x)((x-kt$Fe)/x))                      
avk.fe$x6<-sapply(ad$Fe[6], function(x)((x-kt$Fe)/x))                      
avk.fe$x7<-sapply(ad$Fe[7], function(x)((x-kt$Fe)/x))                      
avk.fe$x8<-sapply(ad$Fe[8], function(x)((x-kt$Fe)/x))                      
avk.fe$x9<-sapply(ad$Fe[9], function(x)((x-kt$Fe)/x)) 
avk.fe$x10<-sapply(ad$Fe[10], function(x)((x-kt$Fe)/x)) 
avk.fe$x11<-sapply(ad$Fe[11], function(x)((x-kt$Fe)/x)) 
avk.fe$x12<-sapply(ad$Fe[12], function(x)((x-kt$Fe)/x)) 
avk.fe$x13<-sapply(ad$Fe[13], function(x)((x-kt$Fe)/x)) 
avk.fe$x14<-sapply(ad$Fe[14], function(x)((x-kt$Fe)/x)) 

avk.a$Fe<-rbind(avk.fe$x1, avk.fe$x2, avk.fe$x3, avk.fe$x4, avk.fe$x5, avk.fe$x6, avk.fe$x7, avk.fe$x7, avk.fe$x8, avk.fe$x9, avk.fe$x10, avk.fe$x11, avk.fe$x12, avk.fe$x13, avk.fe$x14)
avk.Fe<-sort(avk.a$Fe, decreasing=F) 


############################################################################################

#make a matrix to store lower and upper limits for each element
mat4<-matrix(nrow=9, ncol=3) #
colnames(mat4)<-c("element", "ll", "ul")

mat4[1,1]<-"C"; mat4[1,2]<-avk.C[6]*100; mat4[1,3]<-avk.C[248]*100
mat4[2,1]<-"N"; mat4[2,2]<-avk.N[6]*100; mat4[2,3]<-avk.N[248]*100
mat4[3,1]<-"P"; mat4[3,2]<-avk.P[6]*100; mat4[3,3]<-avk.P[248]*100
mat4[4,1]<-"Ca"; mat4[4,2]<-avk.Ca[6]*100; mat4[4,3]<-avk.Ca[248]*100
mat4[5,1]<-"S"; mat4[5,2]<-avk.S[6]*100; mat4[5,3]<-avk.S[248]*100
mat4[6,1]<-"K"; mat4[6,2]<-avk.K[6]*100; mat4[6,3]<-avk.K[248]*100
mat4[7,1]<-"Mg"; mat4[7,2]<-avk.Mg[6]*100; mat4[7,3]<-avk.Mg[248]*100
mat4[8,1]<-"Na"; mat4[8,2]<-avk.Na[6]*100; mat4[8,3]<-avk.Na[248]*100
mat4[9,1]<-"Fe"; mat4[9,2]<-avk.Fe[6]*100; mat4[9,3]<-avk.Fe[248]*100

#########################################################################################
#Confidence intervals for Adult vs. Smolt
###Make confidence intervals on % difference

#ADULTS VS SMOLTS

avs.p<-NULL
avs.p<-data.frame(y=sm$P)
avs.p$x1<-sapply(ad$P[1], function(x)((x-sm$P)/x))
avs.p$x2<-sapply(ad$P[2], function(x)((x-sm$P)/x))
avs.p$x3<-sapply(ad$P[3], function(x)((x-sm$P)/x))                      
avs.p$x4<-sapply(ad$P[4], function(x)((x-sm$P)/x))             
avs.p$x5<-sapply(ad$P[5], function(x)((x-sm$P)/x))                      
avs.p$x6<-sapply(ad$P[6], function(x)((x-sm$P)/x))                      
avs.p$x7<-sapply(ad$P[7], function(x)((x-sm$P)/x))                      
avs.p$x8<-sapply(ad$P[8], function(x)((x-sm$P)/x))                      
avs.p$x9<-sapply(ad$P[9], function(x)((x-sm$P)/x)) 
avs.p$x10<-sapply(ad$P[10], function(x)((x-sm$P)/x)) 
avs.p$x11<-sapply(ad$P[11], function(x)((x-sm$P)/x)) 
avs.p$x12<-sapply(ad$P[12], function(x)((x-sm$P)/x)) 
avs.p$x13<-sapply(ad$P[13], function(x)((x-sm$P)/x)) 
avs.p$x14<-sapply(ad$P[14], function(x)((x-sm$P)/x)) 

#make dataframe to hold all combinations for all elements
avs.a<-NULL
avs.a<-data.frame(P=rbind(avs.p$x1, avs.p$x2, avs.p$x3, avs.p$x4, avs.p$x5, avs.p$x6, avs.p$x7, avs.p$x7, avs.p$x8, avs.p$x9, avs.p$x10, avs.p$x11, avs.p$x12, avs.p$x13, avs.p$x14))
avs.P<-sort(avs.a$P, decreasing=F)                      
#Then 255*0.975 = 249, so the upper limit is 6 backwards from the highest value, so -0.84
#Lower limit is 255*0.025 = 6, so 6 forwards from lowest value is -2.53


avs.c<-NULL
avs.c<-data.frame(y=sm$C)
avs.c$x1<-sapply(ad$C[1], function(x)((x-sm$C)/x))
avs.c$x2<-sapply(ad$C[2], function(x)((x-sm$C)/x))
avs.c$x3<-sapply(ad$C[3], function(x)((x-sm$C)/x))                      
avs.c$x4<-sapply(ad$C[4], function(x)((x-sm$C)/x))             
avs.c$x5<-sapply(ad$C[5], function(x)((x-sm$C)/x))                      
avs.c$x6<-sapply(ad$C[6], function(x)((x-sm$C)/x))                      
avs.c$x7<-sapply(ad$C[7], function(x)((x-sm$C)/x))                      
avs.c$x8<-sapply(ad$C[8], function(x)((x-sm$C)/x))                      
avs.c$x9<-sapply(ad$C[9], function(x)((x-sm$C)/x)) 
avs.c$x10<-sapply(ad$C[10], function(x)((x-sm$C)/x)) 
avs.c$x11<-sapply(ad$C[11], function(x)((x-sm$C)/x)) 
avs.c$x12<-sapply(ad$C[12], function(x)((x-sm$C)/x)) 
avs.c$x13<-sapply(ad$C[13], function(x)((x-sm$C)/x)) 
avs.c$x14<-sapply(ad$C[14], function(x)((x-sm$C)/x)) 

avs.a$C<-rbind(avs.c$x1, avs.c$x2, avs.c$x3, avs.c$x4, avs.c$x5, avs.c$x6, avs.c$x7, avs.c$x7, avs.c$x8, avs.c$x9, avs.c$x10, avs.c$x11, avs.c$x12, avs.c$x13, avs.c$x14)
avs.C<-sort(avs.a$C, decreasing=F)   
#Nitrogen
avs.n<-NULL
avs.n<-data.frame(y=sm$N)
avs.n$x1<-sapply(ad$N[1], function(x)((x-sm$N)/x))
avs.n$x2<-sapply(ad$N[2], function(x)((x-sm$N)/x))
avs.n$x3<-sapply(ad$N[3], function(x)((x-sm$N)/x))                      
avs.n$x4<-sapply(ad$N[4], function(x)((x-sm$N)/x))             
avs.n$x5<-sapply(ad$N[5], function(x)((x-sm$N)/x))                      
avs.n$x6<-sapply(ad$N[6], function(x)((x-sm$N)/x))                      
avs.n$x7<-sapply(ad$N[7], function(x)((x-sm$N)/x))                      
avs.n$x8<-sapply(ad$N[8], function(x)((x-sm$N)/x))                      
avs.n$x9<-sapply(ad$N[9], function(x)((x-sm$N)/x)) 
avs.n$x10<-sapply(ad$N[10], function(x)((x-sm$N)/x)) 
avs.n$x11<-sapply(ad$N[11], function(x)((x-sm$N)/x)) 
avs.n$x12<-sapply(ad$N[12], function(x)((x-sm$N)/x)) 
avs.n$x13<-sapply(ad$N[13], function(x)((x-sm$N)/x)) 
avs.n$x14<-sapply(ad$N[14], function(x)((x-sm$N)/x)) 

avs.a$N<-rbind(avs.n$x1, avs.n$x2, avs.n$x3, avs.n$x4, avs.n$x5, avs.n$x6, avs.n$x7, avs.n$x7, avs.n$x8, avs.n$x9, avs.n$x10, avs.n$x11, avs.n$x12, avs.n$x13, avs.n$x14)
avs.N<-sort(avs.a$N, decreasing=F)  


#Calcium
avs.ca<-NULL
avs.ca<-data.frame(y=sm$Ca)
avs.ca$x1<-sapply(ad$Ca[1], function(x)((x-sm$Ca)/x))
avs.ca$x2<-sapply(ad$Ca[2], function(x)((x-sm$Ca)/x))
avs.ca$x3<-sapply(ad$Ca[3], function(x)((x-sm$Ca)/x))                      
avs.ca$x4<-sapply(ad$Ca[4], function(x)((x-sm$Ca)/x))             
avs.ca$x5<-sapply(ad$Ca[5], function(x)((x-sm$Ca)/x))                      
avs.ca$x6<-sapply(ad$Ca[6], function(x)((x-sm$Ca)/x))                      
avs.ca$x7<-sapply(ad$Ca[7], function(x)((x-sm$Ca)/x))                      
avs.ca$x8<-sapply(ad$Ca[8], function(x)((x-sm$Ca)/x))                      
avs.ca$x9<-sapply(ad$Ca[9], function(x)((x-sm$Ca)/x)) 
avs.ca$x10<-sapply(ad$Ca[10], function(x)((x-sm$Ca)/x)) 
avs.ca$x11<-sapply(ad$Ca[11], function(x)((x-sm$Ca)/x)) 
avs.ca$x12<-sapply(ad$Ca[12], function(x)((x-sm$Ca)/x)) 
avs.ca$x13<-sapply(ad$Ca[13], function(x)((x-sm$Ca)/x)) 
avs.ca$x14<-sapply(ad$Ca[14], function(x)((x-sm$Ca)/x)) 

avs.a$Ca<-rbind(avs.ca$x1, avs.ca$x2, avs.ca$x3, avs.ca$x4, avs.ca$x5, avs.ca$x6, avs.ca$x7, avs.ca$x7, avs.ca$x8, avs.ca$x9, avs.ca$x10, avs.ca$x11, avs.ca$x12, avs.ca$x13, avs.ca$x14)
avs.Ca<-sort(avs.a$Ca, decreasing=F) 
###########################################################################

#Sulfur
avs.s<-NULL
avs.s<-data.frame(y=sm$S)
avs.s$x1<-sapply(ad$S[1], function(x)((x-sm$S)/x))
avs.s$x2<-sapply(ad$S[2], function(x)((x-sm$S)/x))
avs.s$x3<-sapply(ad$S[3], function(x)((x-sm$S)/x))                      
avs.s$x4<-sapply(ad$S[4], function(x)((x-sm$S)/x))             
avs.s$x5<-sapply(ad$S[5], function(x)((x-sm$S)/x))                      
avs.s$x6<-sapply(ad$S[6], function(x)((x-sm$S)/x))                      
avs.s$x7<-sapply(ad$S[7], function(x)((x-sm$S)/x))                      
avs.s$x8<-sapply(ad$S[8], function(x)((x-sm$S)/x))                      
avs.s$x9<-sapply(ad$S[9], function(x)((x-sm$S)/x)) 
avs.s$x10<-sapply(ad$S[10], function(x)((x-sm$S)/x)) 
avs.s$x11<-sapply(ad$S[11], function(x)((x-sm$S)/x)) 
avs.s$x12<-sapply(ad$S[12], function(x)((x-sm$S)/x)) 
avs.s$x13<-sapply(ad$S[13], function(x)((x-sm$S)/x)) 
avs.s$x14<-sapply(ad$S[14], function(x)((x-sm$S)/x)) 

avs.a$S<-rbind(avs.s$x1, avs.s$x2, avs.s$x3, avs.s$x4, avs.s$x5, avs.s$x6, avs.s$x7, avs.s$x7, avs.s$x8, avs.s$x9, avs.s$x10, avs.s$x11, avs.s$x12, avs.s$x13, avs.s$x14)
avs.S<-sort(avs.a$S, decreasing=F) 

####################################################################################

#Potassium
avs.k<-NULL
avs.k<-data.frame(y=sm$K)
avs.k$x1<-sapply(ad$K[1], function(x)((x-sm$K)/x))
avs.k$x2<-sapply(ad$K[2], function(x)((x-sm$K)/x))
avs.k$x3<-sapply(ad$K[3], function(x)((x-sm$K)/x))                      
avs.k$x4<-sapply(ad$K[4], function(x)((x-sm$K)/x))             
avs.k$x5<-sapply(ad$K[5], function(x)((x-sm$K)/x))                      
avs.k$x6<-sapply(ad$K[6], function(x)((x-sm$K)/x))                      
avs.k$x7<-sapply(ad$K[7], function(x)((x-sm$K)/x))                      
avs.k$x8<-sapply(ad$K[8], function(x)((x-sm$K)/x))                      
avs.k$x9<-sapply(ad$K[9], function(x)((x-sm$K)/x)) 
avs.k$x10<-sapply(ad$K[10], function(x)((x-sm$K)/x)) 
avs.k$x11<-sapply(ad$K[11], function(x)((x-sm$K)/x)) 
avs.k$x12<-sapply(ad$K[12], function(x)((x-sm$K)/x)) 
avs.k$x13<-sapply(ad$K[13], function(x)((x-sm$K)/x)) 
avs.k$x14<-sapply(ad$K[14], function(x)((x-sm$K)/x)) 

avs.a$K<-rbind(avs.k$x1, avs.k$x2, avs.k$x3, avs.k$x4, avs.k$x5, avs.k$x6, avs.k$x7, avs.k$x7, avs.k$x8, avs.k$x9, avs.k$x10, avs.k$x11, avs.k$x12, avs.k$x13, avs.k$x14)
avs.K<-sort(avs.a$K, decreasing=F) 

######################################################################
#Magnesium
avs.mg<-NULL
avs.mg<-data.frame(y=sm$Mg)
avs.mg$x1<-sapply(ad$Mg[1], function(x)((x-sm$Mg)/x))
avs.mg$x2<-sapply(ad$Mg[2], function(x)((x-sm$Mg)/x))
avs.mg$x3<-sapply(ad$Mg[3], function(x)((x-sm$Mg)/x))                      
avs.mg$x4<-sapply(ad$Mg[4], function(x)((x-sm$Mg)/x))             
avs.mg$x5<-sapply(ad$Mg[5], function(x)((x-sm$Mg)/x))                      
avs.mg$x6<-sapply(ad$Mg[6], function(x)((x-sm$Mg)/x))                      
avs.mg$x7<-sapply(ad$Mg[7], function(x)((x-sm$Mg)/x))                      
avs.mg$x8<-sapply(ad$Mg[8], function(x)((x-sm$Mg)/x))                      
avs.mg$x9<-sapply(ad$Mg[9], function(x)((x-sm$Mg)/x)) 
avs.mg$x10<-sapply(ad$Mg[10], function(x)((x-sm$Mg)/x)) 
avs.mg$x11<-sapply(ad$Mg[11], function(x)((x-sm$Mg)/x)) 
avs.mg$x12<-sapply(ad$Mg[12], function(x)((x-sm$Mg)/x)) 
avs.mg$x13<-sapply(ad$Mg[13], function(x)((x-sm$Mg)/x)) 
avs.mg$x14<-sapply(ad$Mg[14], function(x)((x-sm$Mg)/x)) 

avs.a$Mg<-rbind(avs.mg$x1, avs.mg$x2, avs.mg$x3, avs.mg$x4, avs.mg$x5, avs.mg$x6, avs.mg$x7, avs.mg$x7, avs.mg$x8, avs.mg$x9, avs.mg$x10, avs.mg$x11, avs.mg$x12, avs.mg$x13, avs.mg$x14)
avs.Mg<-sort(avs.a$Mg, decreasing=F) 

######################################################################
#Sodium
avs.na<-NULL
avs.na<-data.frame(y=sm$Na)
avs.na$x1<-sapply(ad$Na[1], function(x)((x-sm$Na)/x))
avs.na$x2<-sapply(ad$Na[2], function(x)((x-sm$Na)/x))
avs.na$x3<-sapply(ad$Na[3], function(x)((x-sm$Na)/x))                      
avs.na$x4<-sapply(ad$Na[4], function(x)((x-sm$Na)/x))             
avs.na$x5<-sapply(ad$Na[5], function(x)((x-sm$Na)/x))                      
avs.na$x6<-sapply(ad$Na[6], function(x)((x-sm$Na)/x))                      
avs.na$x7<-sapply(ad$Na[7], function(x)((x-sm$Na)/x))                      
avs.na$x8<-sapply(ad$Na[8], function(x)((x-sm$Na)/x))                      
avs.na$x9<-sapply(ad$Na[9], function(x)((x-sm$Na)/x)) 
avs.na$x10<-sapply(ad$Na[10], function(x)((x-sm$Na)/x)) 
avs.na$x11<-sapply(ad$Na[11], function(x)((x-sm$Na)/x)) 
avs.na$x12<-sapply(ad$Na[12], function(x)((x-sm$Na)/x)) 
avs.na$x13<-sapply(ad$Na[13], function(x)((x-sm$Na)/x)) 
avs.na$x14<-sapply(ad$Na[14], function(x)((x-sm$Na)/x)) 

avs.a$Na<-rbind(avs.na$x1, avs.na$x2, avs.na$x3, avs.na$x4, avs.na$x5, avs.na$x6, avs.na$x7, avs.na$x7, avs.na$x8, avs.na$x9, avs.na$x10, avs.na$x11, avs.na$x12, avs.na$x13, avs.na$x14)
avs.Na<-sort(avs.a$Na, decreasing=F) 


############################################################################################
#Iron

avs.fe<-NULL
avs.fe<-data.frame(y=sm$Fe)
avs.fe$x1<-sapply(ad$Fe[1], function(x)((x-sm$Fe)/x))
avs.fe$x2<-sapply(ad$Fe[2], function(x)((x-sm$Fe)/x))
avs.fe$x3<-sapply(ad$Fe[3], function(x)((x-sm$Fe)/x))                      
avs.fe$x4<-sapply(ad$Fe[4], function(x)((x-sm$Fe)/x))             
avs.fe$x5<-sapply(ad$Fe[5], function(x)((x-sm$Fe)/x))                      
avs.fe$x6<-sapply(ad$Fe[6], function(x)((x-sm$Fe)/x))                      
avs.fe$x7<-sapply(ad$Fe[7], function(x)((x-sm$Fe)/x))                      
avs.fe$x8<-sapply(ad$Fe[8], function(x)((x-sm$Fe)/x))                      
avs.fe$x9<-sapply(ad$Fe[9], function(x)((x-sm$Fe)/x)) 
avs.fe$x10<-sapply(ad$Fe[10], function(x)((x-sm$Fe)/x)) 
avs.fe$x11<-sapply(ad$Fe[11], function(x)((x-sm$Fe)/x)) 
avs.fe$x12<-sapply(ad$Fe[12], function(x)((x-sm$Fe)/x)) 
avs.fe$x13<-sapply(ad$Fe[13], function(x)((x-sm$Fe)/x)) 
avs.fe$x14<-sapply(ad$Fe[14], function(x)((x-sm$Fe)/x)) 

avs.a$Fe<-rbind(avs.fe$x1, avs.fe$x2, avs.fe$x3, avs.fe$x4, avs.fe$x5, avs.fe$x6, avs.fe$x7, avs.fe$x7, avs.fe$x8, avs.fe$x9, avs.fe$x10, avs.fe$x11, avs.fe$x12, avs.fe$x13, avs.fe$x14)
avs.Fe<-sort(avs.a$Fe, decreasing=F) 


############################################################################################

#make a matrix to store lower and upper limits for each element
mat5<-matrix(nrow=9, ncol=3) #
colnames(mat5)<-c("element", "ll", "ul")

mat5[1,1]<-"C"; mat5[1,2]<-avs.C[6]*100; mat5[1,3]<-avs.C[220]*100
mat5[2,1]<-"N"; mat5[2,2]<-avs.N[6]*100; mat5[2,3]<-avs.N[220]*100
mat5[3,1]<-"P"; mat5[3,2]<-avs.P[6]*100; mat5[3,3]<-avs.P[220]*100
mat5[4,1]<-"Ca"; mat5[4,2]<-avs.Ca[6]*100; mat5[4,3]<-avs.Ca[220]*100
mat5[5,1]<-"S"; mat5[5,2]<-avs.S[6]*100; mat5[5,3]<-avs.S[220]*100
mat5[6,1]<-"K"; mat5[6,2]<-avs.K[6]*100; mat5[6,3]<-avs.K[220]*100
mat5[7,1]<-"Mg"; mat5[7,2]<-avs.Mg[6]*100; mat5[7,3]<-avs.Mg[220]*100
mat5[8,1]<-"Na"; mat5[8,2]<-avs.Na[6]*100; mat5[8,3]<-avs.Na[220]*100
mat5[9,1]<-"Fe"; mat5[9,2]<-avs.Fe[6]*100; mat5[9,3]<-avs.Fe[220]*100

#########################################################################################

###Make confidence intervals on % difference

#ktULTS VS SMOLTS

kvs.p<-NULL
kvs.p<-data.frame(y=sm$P)
kvs.p$x1<-sapply(kt$P[1], function(x)((x-sm$P)/x))
kvs.p$x2<-sapply(kt$P[2], function(x)((x-sm$P)/x))
kvs.p$x3<-sapply(kt$P[3], function(x)((x-sm$P)/x))                      
kvs.p$x4<-sapply(kt$P[4], function(x)((x-sm$P)/x))             
kvs.p$x5<-sapply(kt$P[5], function(x)((x-sm$P)/x))                      
kvs.p$x6<-sapply(kt$P[6], function(x)((x-sm$P)/x))                      
kvs.p$x7<-sapply(kt$P[7], function(x)((x-sm$P)/x))                      
kvs.p$x8<-sapply(kt$P[8], function(x)((x-sm$P)/x))                      
kvs.p$x9<-sapply(kt$P[9], function(x)((x-sm$P)/x)) 
kvs.p$x10<-sapply(kt$P[10], function(x)((x-sm$P)/x)) 
kvs.p$x11<-sapply(kt$P[11], function(x)((x-sm$P)/x)) 
kvs.p$x12<-sapply(kt$P[12], function(x)((x-sm$P)/x)) 
kvs.p$x13<-sapply(kt$P[13], function(x)((x-sm$P)/x)) 
kvs.p$x14<-sapply(kt$P[14], function(x)((x-sm$P)/x)) 
kvs.p$x15<-sapply(kt$P[15], function(x)((x-sm$P)/x)) 
kvs.p$x16<-sapply(kt$P[16], function(x)((x-sm$P)/x)) 
kvs.p$x17<-sapply(kt$P[17], function(x)((x-sm$P)/x)) 



#make dataframe to hold all combinations for all elements
kvs.a<-NULL
kvs.a<-data.frame(P=rbind(kvs.p$x1, kvs.p$x2, kvs.p$x3, kvs.p$x4, kvs.p$x5, kvs.p$x6, kvs.p$x7, kvs.p$x7, kvs.p$x8, kvs.p$x9, kvs.p$x10, kvs.p$x11, kvs.p$x12, kvs.p$x13, kvs.p$x14, kvs.p$x15, kvs.p$x16, kvs.p$x17))
kvs.P<-sort(kvs.a$P, decreasing=F)                      
#Then 255*0.975 = 249, so the upper limit is 6 backwards from the highest value, so -0.84
#Lower limit is 255*0.025 = 6, so 6 forwards from lowest value is -2.53

#####################################################################################################

#Carbon
kvs.c<-NULL
kvs.c<-data.frame(y=sm$C)
kvs.c$x1<-sapply(kt$C[1], function(x)((x-sm$C)/x))
kvs.c$x2<-sapply(kt$C[2], function(x)((x-sm$C)/x))
kvs.c$x3<-sapply(kt$C[3], function(x)((x-sm$C)/x))                      
kvs.c$x4<-sapply(kt$C[4], function(x)((x-sm$C)/x))             
kvs.c$x5<-sapply(kt$C[5], function(x)((x-sm$C)/x))                      
kvs.c$x6<-sapply(kt$C[6], function(x)((x-sm$C)/x))                      
kvs.c$x7<-sapply(kt$C[7], function(x)((x-sm$C)/x))                      
kvs.c$x8<-sapply(kt$C[8], function(x)((x-sm$C)/x))                      
kvs.c$x9<-sapply(kt$C[9], function(x)((x-sm$C)/x)) 
kvs.c$x10<-sapply(kt$C[10], function(x)((x-sm$C)/x)) 
kvs.c$x11<-sapply(kt$C[11], function(x)((x-sm$C)/x)) 
kvs.c$x12<-sapply(kt$C[12], function(x)((x-sm$C)/x)) 
kvs.c$x13<-sapply(kt$C[13], function(x)((x-sm$C)/x)) 
kvs.c$x14<-sapply(kt$C[14], function(x)((x-sm$C)/x)) 
kvs.c$x15<-sapply(kt$C[15], function(x)((x-sm$C)/x)) 
kvs.c$x16<-sapply(kt$C[16], function(x)((x-sm$C)/x)) 
kvs.c$x17<-sapply(kt$C[17], function(x)((x-sm$C)/x)) 


kvs.a$C<-rbind(kvs.c$x1, kvs.c$x2, kvs.c$x3, kvs.c$x4, kvs.c$x5, kvs.c$x6, kvs.c$x7, kvs.c$x7, kvs.c$x8, kvs.c$x9, kvs.c$x10, kvs.c$x11, kvs.c$x12, kvs.c$x13, kvs.c$x14, kvs.c$x15, kvs.c$x16, kvs.c$x17)
kvs.C<-sort(kvs.a$C, decreasing=F)   
#Nitrogen
kvs.n<-NULL
kvs.n<-data.frame(y=sm$N)
kvs.n$x1<-sapply(kt$N[1], function(x)((x-sm$N)/x))
kvs.n$x2<-sapply(kt$N[2], function(x)((x-sm$N)/x))
kvs.n$x3<-sapply(kt$N[3], function(x)((x-sm$N)/x))                      
kvs.n$x4<-sapply(kt$N[4], function(x)((x-sm$N)/x))             
kvs.n$x5<-sapply(kt$N[5], function(x)((x-sm$N)/x))                      
kvs.n$x6<-sapply(kt$N[6], function(x)((x-sm$N)/x))                      
kvs.n$x7<-sapply(kt$N[7], function(x)((x-sm$N)/x))                      
kvs.n$x8<-sapply(kt$N[8], function(x)((x-sm$N)/x))                      
kvs.n$x9<-sapply(kt$N[9], function(x)((x-sm$N)/x)) 
kvs.n$x10<-sapply(kt$N[10], function(x)((x-sm$N)/x)) 
kvs.n$x11<-sapply(kt$N[11], function(x)((x-sm$N)/x)) 
kvs.n$x12<-sapply(kt$N[12], function(x)((x-sm$N)/x)) 
kvs.n$x13<-sapply(kt$N[13], function(x)((x-sm$N)/x)) 
kvs.n$x14<-sapply(kt$N[14], function(x)((x-sm$N)/x)) 
kvs.n$x15<-sapply(kt$N[15], function(x)((x-sm$N)/x)) 
kvs.n$x16<-sapply(kt$N[16], function(x)((x-sm$N)/x)) 
kvs.n$x17<-sapply(kt$N[17], function(x)((x-sm$N)/x)) 

kvs.a$N<-rbind(kvs.n$x1, kvs.n$x2, kvs.n$x3, kvs.n$x4, kvs.n$x5, kvs.n$x6, kvs.n$x7, kvs.n$x7, kvs.n$x8, kvs.n$x9, kvs.n$x10, kvs.n$x11, kvs.n$x12, kvs.n$x13, kvs.n$x14, kvs.n$x15, kvs.n$x16, kvs.n$x17)
kvs.N<-sort(kvs.a$N, decreasing=F)  


#Calcium
kvs.ca<-NULL
kvs.ca<-data.frame(y=sm$Ca)
kvs.ca$x1<-sapply(kt$Ca[1], function(x)((x-sm$Ca)/x))
kvs.ca$x2<-sapply(kt$Ca[2], function(x)((x-sm$Ca)/x))
kvs.ca$x3<-sapply(kt$Ca[3], function(x)((x-sm$Ca)/x))                      
kvs.ca$x4<-sapply(kt$Ca[4], function(x)((x-sm$Ca)/x))             
kvs.ca$x5<-sapply(kt$Ca[5], function(x)((x-sm$Ca)/x))                      
kvs.ca$x6<-sapply(kt$Ca[6], function(x)((x-sm$Ca)/x))                      
kvs.ca$x7<-sapply(kt$Ca[7], function(x)((x-sm$Ca)/x))                      
kvs.ca$x8<-sapply(kt$Ca[8], function(x)((x-sm$Ca)/x))                      
kvs.ca$x9<-sapply(kt$Ca[9], function(x)((x-sm$Ca)/x)) 
kvs.ca$x10<-sapply(kt$Ca[10], function(x)((x-sm$Ca)/x)) 
kvs.ca$x11<-sapply(kt$Ca[11], function(x)((x-sm$Ca)/x)) 
kvs.ca$x12<-sapply(kt$Ca[12], function(x)((x-sm$Ca)/x)) 
kvs.ca$x13<-sapply(kt$Ca[13], function(x)((x-sm$Ca)/x)) 
kvs.ca$x14<-sapply(kt$Ca[14], function(x)((x-sm$Ca)/x)) 
kvs.ca$x15<-sapply(kt$Ca[15], function(x)((x-sm$Ca)/x)) 
kvs.ca$x16<-sapply(kt$Ca[16], function(x)((x-sm$Ca)/x)) 
kvs.ca$x17<-sapply(kt$Ca[17], function(x)((x-sm$Ca)/x)) 

kvs.a$Ca<-rbind(kvs.ca$x1, kvs.ca$x2, kvs.ca$x3, kvs.ca$x4, kvs.ca$x5, kvs.ca$x6, kvs.ca$x7, kvs.ca$x7, kvs.ca$x8, kvs.ca$x9, kvs.ca$x10, kvs.ca$x11, kvs.ca$x12, kvs.ca$x13, kvs.ca$x14, kvs.ca$x15, kvs.ca$x16, kvs.ca$x17)
kvs.Ca<-sort(kvs.a$Ca, decreasing=F) 
###########################################################################

#Sulfur
kvs.s<-NULL
kvs.s<-data.frame(y=sm$S)
kvs.s$x1<-sapply(kt$S[1], function(x)((x-sm$S)/x))
kvs.s$x2<-sapply(kt$S[2], function(x)((x-sm$S)/x))
kvs.s$x3<-sapply(kt$S[3], function(x)((x-sm$S)/x))                      
kvs.s$x4<-sapply(kt$S[4], function(x)((x-sm$S)/x))             
kvs.s$x5<-sapply(kt$S[5], function(x)((x-sm$S)/x))                      
kvs.s$x6<-sapply(kt$S[6], function(x)((x-sm$S)/x))                      
kvs.s$x7<-sapply(kt$S[7], function(x)((x-sm$S)/x))                      
kvs.s$x8<-sapply(kt$S[8], function(x)((x-sm$S)/x))                      
kvs.s$x9<-sapply(kt$S[9], function(x)((x-sm$S)/x)) 
kvs.s$x10<-sapply(kt$S[10], function(x)((x-sm$S)/x)) 
kvs.s$x11<-sapply(kt$S[11], function(x)((x-sm$S)/x)) 
kvs.s$x12<-sapply(kt$S[12], function(x)((x-sm$S)/x)) 
kvs.s$x13<-sapply(kt$S[13], function(x)((x-sm$S)/x)) 
kvs.s$x14<-sapply(kt$S[14], function(x)((x-sm$S)/x)) 
kvs.s$x15<-sapply(kt$S[15], function(x)((x-sm$S)/x)) 
kvs.s$x16<-sapply(kt$S[16], function(x)((x-sm$S)/x)) 
kvs.s$x17<-sapply(kt$S[17], function(x)((x-sm$S)/x)) 

kvs.a$S<-rbind(kvs.s$x1, kvs.s$x2, kvs.s$x3, kvs.s$x4, kvs.s$x5, kvs.s$x6, kvs.s$x7, kvs.s$x7, kvs.s$x8, kvs.s$x9, kvs.s$x10, kvs.s$x11, kvs.s$x12, kvs.s$x13, kvs.s$x14, kvs.s$x15, kvs.s$x16, kvs.s$x17)
kvs.S<-sort(kvs.a$S, decreasing=F) 

####################################################################################

#Potassium
kvs.k<-NULL
kvs.k<-data.frame(y=sm$K)
kvs.k$x1<-sapply(kt$K[1], function(x)((x-sm$K)/x))
kvs.k$x2<-sapply(kt$K[2], function(x)((x-sm$K)/x))
kvs.k$x3<-sapply(kt$K[3], function(x)((x-sm$K)/x))                      
kvs.k$x4<-sapply(kt$K[4], function(x)((x-sm$K)/x))             
kvs.k$x5<-sapply(kt$K[5], function(x)((x-sm$K)/x))                      
kvs.k$x6<-sapply(kt$K[6], function(x)((x-sm$K)/x))                      
kvs.k$x7<-sapply(kt$K[7], function(x)((x-sm$K)/x))                      
kvs.k$x8<-sapply(kt$K[8], function(x)((x-sm$K)/x))                      
kvs.k$x9<-sapply(kt$K[9], function(x)((x-sm$K)/x)) 
kvs.k$x10<-sapply(kt$K[10], function(x)((x-sm$K)/x)) 
kvs.k$x11<-sapply(kt$K[11], function(x)((x-sm$K)/x)) 
kvs.k$x12<-sapply(kt$K[12], function(x)((x-sm$K)/x)) 
kvs.k$x13<-sapply(kt$K[13], function(x)((x-sm$K)/x)) 
kvs.k$x14<-sapply(kt$K[14], function(x)((x-sm$K)/x)) 
kvs.k$x15<-sapply(kt$K[15], function(x)((x-sm$K)/x)) 
kvs.k$x16<-sapply(kt$K[16], function(x)((x-sm$K)/x)) 
kvs.k$x17<-sapply(kt$K[17], function(x)((x-sm$K)/x)) 

kvs.a$K<-rbind(kvs.k$x1, kvs.k$x2, kvs.k$x3, kvs.k$x4, kvs.k$x5, kvs.k$x6, kvs.k$x7, kvs.k$x7, kvs.k$x8, kvs.k$x9, kvs.k$x10, kvs.k$x11, kvs.k$x12, kvs.k$x13, kvs.k$x14, kvs.k$x15, kvs.k$x16, kvs.k$x17)
kvs.K<-sort(kvs.a$K, decreasing=F) 

######################################################################
#Magnesium
kvs.mg<-NULL
kvs.mg<-data.frame(y=sm$Mg)
kvs.mg$x1<-sapply(kt$Mg[1], function(x)((x-sm$Mg)/x))
kvs.mg$x2<-sapply(kt$Mg[2], function(x)((x-sm$Mg)/x))
kvs.mg$x3<-sapply(kt$Mg[3], function(x)((x-sm$Mg)/x))                      
kvs.mg$x4<-sapply(kt$Mg[4], function(x)((x-sm$Mg)/x))             
kvs.mg$x5<-sapply(kt$Mg[5], function(x)((x-sm$Mg)/x))                      
kvs.mg$x6<-sapply(kt$Mg[6], function(x)((x-sm$Mg)/x))                      
kvs.mg$x7<-sapply(kt$Mg[7], function(x)((x-sm$Mg)/x))                      
kvs.mg$x8<-sapply(kt$Mg[8], function(x)((x-sm$Mg)/x))                      
kvs.mg$x9<-sapply(kt$Mg[9], function(x)((x-sm$Mg)/x)) 
kvs.mg$x10<-sapply(kt$Mg[10], function(x)((x-sm$Mg)/x)) 
kvs.mg$x11<-sapply(kt$Mg[11], function(x)((x-sm$Mg)/x)) 
kvs.mg$x12<-sapply(kt$Mg[12], function(x)((x-sm$Mg)/x)) 
kvs.mg$x13<-sapply(kt$Mg[13], function(x)((x-sm$Mg)/x)) 
kvs.mg$x14<-sapply(kt$Mg[14], function(x)((x-sm$Mg)/x)) 
kvs.mg$x15<-sapply(kt$Mg[15], function(x)((x-sm$Mg)/x)) 
kvs.mg$x16<-sapply(kt$Mg[16], function(x)((x-sm$Mg)/x)) 
kvs.mg$x17<-sapply(kt$Mg[17], function(x)((x-sm$Mg)/x)) 

kvs.a$Mg<-rbind(kvs.mg$x1, kvs.mg$x2, kvs.mg$x3, kvs.mg$x4, kvs.mg$x5, kvs.mg$x6, kvs.mg$x7, kvs.mg$x7, kvs.mg$x8, kvs.mg$x9, kvs.mg$x10, kvs.mg$x11, kvs.mg$x12, kvs.mg$x13, kvs.mg$x14, kvs.mg$x15, kvs.mg$x16, kvs.mg$x17)
kvs.Mg<-sort(kvs.a$Mg, decreasing=F) 

######################################################################
#Sodium
kvs.na<-NULL
kvs.na<-data.frame(y=sm$Na)
kvs.na$x1<-sapply(kt$Na[1], function(x)((x-sm$Na)/x))
kvs.na$x2<-sapply(kt$Na[2], function(x)((x-sm$Na)/x))
kvs.na$x3<-sapply(kt$Na[3], function(x)((x-sm$Na)/x))                      
kvs.na$x4<-sapply(kt$Na[4], function(x)((x-sm$Na)/x))             
kvs.na$x5<-sapply(kt$Na[5], function(x)((x-sm$Na)/x))                      
kvs.na$x6<-sapply(kt$Na[6], function(x)((x-sm$Na)/x))                      
kvs.na$x7<-sapply(kt$Na[7], function(x)((x-sm$Na)/x))                      
kvs.na$x8<-sapply(kt$Na[8], function(x)((x-sm$Na)/x))                      
kvs.na$x9<-sapply(kt$Na[9], function(x)((x-sm$Na)/x)) 
kvs.na$x10<-sapply(kt$Na[10], function(x)((x-sm$Na)/x)) 
kvs.na$x11<-sapply(kt$Na[11], function(x)((x-sm$Na)/x)) 
kvs.na$x12<-sapply(kt$Na[12], function(x)((x-sm$Na)/x)) 
kvs.na$x13<-sapply(kt$Na[13], function(x)((x-sm$Na)/x)) 
kvs.na$x14<-sapply(kt$Na[14], function(x)((x-sm$Na)/x))
kvs.na$x15<-sapply(kt$Na[15], function(x)((x-sm$Na)/x)) 
kvs.na$x16<-sapply(kt$Na[16], function(x)((x-sm$Na)/x)) 
kvs.na$x17<-sapply(kt$Na[17], function(x)((x-sm$Na)/x)) 

kvs.a$Na<-rbind(kvs.na$x1, kvs.na$x2, kvs.na$x3, kvs.na$x4, kvs.na$x5, kvs.na$x6, kvs.na$x7, kvs.na$x7, kvs.na$x8, kvs.na$x9, kvs.na$x10, kvs.na$x11, kvs.na$x12, kvs.na$x13, kvs.na$x14, kvs.na$x15, kvs.na$x16, kvs.na$x17)
kvs.Na<-sort(kvs.a$Na, decreasing=F) 


############################################################################################
#Iron

kvs.fe<-NULL
kvs.fe<-data.frame(y=sm$Fe)
kvs.fe$x1<-sapply(kt$Fe[1], function(x)((x-sm$Fe)/x))
kvs.fe$x2<-sapply(kt$Fe[2], function(x)((x-sm$Fe)/x))
kvs.fe$x3<-sapply(kt$Fe[3], function(x)((x-sm$Fe)/x))                      
kvs.fe$x4<-sapply(kt$Fe[4], function(x)((x-sm$Fe)/x))             
kvs.fe$x5<-sapply(kt$Fe[5], function(x)((x-sm$Fe)/x))                      
kvs.fe$x6<-sapply(kt$Fe[6], function(x)((x-sm$Fe)/x))                      
kvs.fe$x7<-sapply(kt$Fe[7], function(x)((x-sm$Fe)/x))                      
kvs.fe$x8<-sapply(kt$Fe[8], function(x)((x-sm$Fe)/x))                      
kvs.fe$x9<-sapply(kt$Fe[9], function(x)((x-sm$Fe)/x)) 
kvs.fe$x10<-sapply(kt$Fe[10], function(x)((x-sm$Fe)/x)) 
kvs.fe$x11<-sapply(kt$Fe[11], function(x)((x-sm$Fe)/x)) 
kvs.fe$x12<-sapply(kt$Fe[12], function(x)((x-sm$Fe)/x)) 
kvs.fe$x13<-sapply(kt$Fe[13], function(x)((x-sm$Fe)/x)) 
kvs.fe$x14<-sapply(kt$Fe[14], function(x)((x-sm$Fe)/x)) 
kvs.fe$x15<-sapply(kt$Fe[15], function(x)((x-sm$Fe)/x)) 
kvs.fe$x16<-sapply(kt$Fe[16], function(x)((x-sm$Fe)/x)) 
kvs.fe$x17<-sapply(kt$Fe[17], function(x)((x-sm$Fe)/x))

kvs.a$Fe<-rbind(kvs.fe$x1, kvs.fe$x2, kvs.fe$x3, kvs.fe$x4, kvs.fe$x5, kvs.fe$x6, kvs.fe$x7, kvs.fe$x7, kvs.fe$x8, kvs.fe$x9, kvs.fe$x10, kvs.fe$x11, kvs.fe$x12, kvs.fe$x13, kvs.fe$x14, kvs.fe$x15, kvs.fe$x16, kvs.fe$x17)
kvs.Fe<-sort(kvs.a$Fe, decreasing=F) 


############################################################################################

#make a matrix to store lower and upper limits for each element
mat6<-matrix(nrow=9, ncol=3) #
colnames(mat6)<-c("element", "ll", "ul")

mat6[1,1]<-"C"; mat6[1,2]<-kvs.C[7]*100; mat6[1,3]<-kvs.C[263]*100
mat6[2,1]<-"N"; mat6[2,2]<-kvs.N[7]*100; mat6[2,3]<-kvs.N[263]*100
mat6[3,1]<-"P"; mat6[3,2]<-kvs.P[7]*100; mat6[3,3]<-kvs.P[263]*100
mat6[4,1]<-"Ca"; mat6[4,2]<-kvs.Ca[7]*100; mat6[4,3]<-kvs.Ca[263]*100
mat6[5,1]<-"S"; mat6[5,2]<-kvs.S[7]*100; mat6[5,3]<-kvs.S[263]*100
mat6[6,1]<-"K"; mat6[6,2]<-kvs.K[7]*100; mat6[6,3]<-kvs.K[263]*100
mat6[7,1]<-"Mg"; mat6[7,2]<-kvs.Mg[7]*100; mat6[7,3]<-kvs.Mg[263]*100
mat6[8,1]<-"Na"; mat6[8,2]<-kvs.Na[7]*100; mat6[8,3]<-kvs.Na[263]*100
mat6[9,1]<-"Fe"; mat6[9,2]<-kvs.Fe[7]*100; mat6[9,3]<-kvs.Fe[263]*100

#########################################################################################

avk.ll<-as.numeric(mat4[,2])
avk.ul<-as.numeric(mat4[,3])

avs.ll<-as.numeric(mat5[,2])
avs.ul<-as.numeric(mat5[,3])

kvs.ll<-as.numeric(mat6[,2])
kvs.ul<-as.numeric(mat6[,3])


kvs.1<-cbind(kvs, ll=kvs.ll, ul=kvs.ul)
avs.1<-cbind(avs, ll=avs.ll, ul=avs.ul)
avk.1<-cbind(avk, ll=avk.ll, ul=avk.ul)


#################################################################################################################

#make a plot of percent difference

options(scipen=10) # removes scientific notation from plots
x11(height=6.5, width=4.5)
par(mfrow=c(3,1))
par(oma=c(2,2,1,1)) #sets outer margins
par(mar=c(0.2,2,0.2,1))
par(las=1)
par(mgp=c(1, 1, 0))

#plot element (as a number 1=C, 2=N, 3=P, 4=Ca, 5=S, 6=K, 7=Mg, 8=Na, 9=Fe)
plot(element~perc.diff, data=avs.1, ylim=c(-1, 10), xlim=c(-800, 200), xaxt="n", yaxt="n", ylab="", pch=19, cex=1.5)
arrows(avs.1$ll, avs.1$element,avs.1$ul, avs.1$element, angle=90, code=3, length=0)

abline(v=0, lwd=2)
axis(side=1, labels=F, tck=0.05)
axis(side=2, labels=F, at=c(1,2,3,4,5,6,7,8,9), tck=0.05)

#plot element (as a number 1=C, 2=N, 3=P, 4=Ca, 5=S, 6=K, 7=Mg, 8=Na, 9=Fe)
plot(element~perc.diff, data=avk.1, ylim=c(-1, 10), xlim=c(-800, 200), xaxt="n", yaxt="n", ylab="", pch=19, cex=1.5)
arrows(avk.1$ll, avk.1$element,avk.1$ul, avk.1$element, angle=90, code=3, length=0)

abline(v=0, lwd=2)
axis(side=1, labels=F, tck=0.05)
axis(side=2, labels=F,at=c(1,2,3,4,5,6,7,8,9), tck=0.05)


#plot element (as a number 1=C, 2=N, 3=P, 4=Ca, 5=S, 6=K, 7=Mg, 8=Na, 9=Fe)
plot(element~perc.diff, data=kvs.1, ylim=c(-1, 10), xlim=c(-800, 200), xaxt="n", yaxt="n", ylab="", pch=19, cex=1.5)
arrows(kvs.1$ll, kvs.1$element,kvs.1$ul, kvs.1$element, angle=90, code=3, length=0)
abline(v=0, lwd=2)
axis(side=1, tck=0.05)
axis(side=2, labels=F,at=c(1,2,3,4,5,6,7,8,9),  tck=0.05)

##############################################################################################################

#FIGURE 3 in Ebel et al. JFB

#Using %dry mass, make linear models of %X against %Y  for C, N, P, Ca

#Make new data.frame to plot percent element (This is the same as the initial dataframe, but all values are multiplied by 100)
#Make dataframe for %X on a dry mass basis

dry1<-data.frame(cbind(id=raw$fish.id, 
                       strm=raw$river, 
                       ls=raw$life.stage, 
                       fl=raw$fk.lgt, 
                       ww=raw$cut.wt.g,
                       dw.1=raw$dry.wt/100,#dry weight associated with macropanel analysis. Dry wt determined by freeze drying by UGuelph AFL 
                       dw.2=raw$dry.wt.sil, #dry weight associated with C/N analysis. Dry wt determined by oven drying in Leroux lab
                       P=((raw$P/1000000)/(raw$dry.wt/100))*100, 
                       N=raw$n.dry, 
                       C=raw$c.dry,
                       S=((raw$S/1000000)/(raw$dry.wt/100))*100,
                       Mg=((raw$Mg/1000000)/(raw$dry.wt/100))*100, 
                       K=((raw$K/1000000)/(raw$dry.wt/100))*100,
                       Na=((raw$Na/1000000)/(raw$dry.wt/100))*100,
                       Fe=((raw$Fe/1000000)/(raw$dry.wt/100))*100,
                       Ca=((raw$Ca/1000000)/(raw$dry.wt/100))*100)
)
dry1$ls<-as.factor(dry1$ls)
dry1$strm<-as.factor(dry1$strm)
#####################################

data<-dry1


cor(data$C, data$N, method="pearson")
cor(data$C, data$P, method="pearson")
cor(data$P, data$N, method="pearson")
cor(data$P, data$Ca, method="pearson")

##################################################################################################
#Then plot C, N, P, and Ca
#Subset dataframe into adult, kelt and smolt

data1<-subset(data, ls=="1")
data2<-subset(data, ls=="2")
data3<-subset(data, ls=="3")


#Plot with different life stages using different symbols

### ASSOCIATE EACH ROW WITH ITS OWN MARGINS.

#Make jitter plot of % dry
options(scipen=10) # removes scientific notation from plots
x11(height=5.8, width=5.8)
par(mfrow=c(2,2))
par(oma=c(2,2,1,1)) #sets outer margins
par(mar=c(2,3,2,1))
par(las=1)
par(mgp=c(1, 1, 0))

#C~N
plot(data1$N~data1$C,xlim=c(30, 60), ylim=c(7, 15), pch=16, xlab="", ylab="") 
points(data2$N~data2$C,xlim=c(30, 60), ylim=c(7, 15), pch=8)
points(data3$N~data3$C,xlim=c(30, 60), ylim=c(7, 15), pch=1)


#C~P
plot(data1$P~data1$C,xlim=c(30, 60), ylim=c(0.5, 4), pch=16, xlab="", ylab="") 
points(data2$P~data2$C,xlim=c(30, 60), ylim=c(0.5, 4), pch=8)
points(data3$P~data3$C,xlim=c(30, 60), ylim=c(0.5, 4), pch=1)

#P~N
plot(data1$N~data1$P,xlim=c(0, 4), ylim=c(7, 15), pch=16, xlab="", ylab="") 
points(data2$N~data2$P,xlim=c(0, 4), ylim=c(7, 15), pch=8)
points(data3$N~data3$P,xlim=c(0, 4), ylim=c(7, 15), pch=1)


#P~Ca
plot(data1$Ca~data1$P,xlim=c(0, 4), ylim=c(0, 7), pch=16, xlab="", ylab="") 
points(data2$Ca~data2$P,xlim=c(0, 4), ylim=c(0, 7), pch=8)
points(data3$Ca~data3$P,xlim=c(0, 4), ylim=c(0, 7), pch=1)






